## genomeview - a python module for visualizing genomic data

[![ci](https://github.com/nspies/genomeview/actions/workflows/ci.yml/badge.svg)](https://github.com/nspies/genomeview/actions/workflows/ci.yml)
[![PyPI](https://img.shields.io/pypi/v/genomeview.svg)](https://pypi.org/project/genomeview/)
[![Docs](https://readthedocs.org/projects/genomeview/badge/?version=latest)](https://genomeview.readthedocs.io/en/latest/?badge=latest)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/nspies/genomeview/HEAD?labpath=examples%2Fexamples.ipynb)

![genomeview example image](https://raw.githubusercontent.com/nspies/genomeview/master/docs/images/overview.svg?sanitize=true)

Example [jupyter notebook](https://nbviewer.org/github/nspies/genomeview/blob/main/examples/examples.ipynb) with visualizations inline.

See the [documentation on read-the-docs](http://genomeview.readthedocs.io/en/latest/index.html) for installation and usage

Try it on [mybinder](https://mybinder.org/v2/gh/nspies/genomeview/HEAD?labpath=examples%2Fexamples.ipynb)
